aboutsummaryrefslogtreecommitdiff
path: root/src/target/adi_v5_swd.c
diff options
context:
space:
mode:
authorAndreas Fritiofson <andreas.fritiofson@gmail.com>2016-02-22 23:15:52 +0100
committerAndreas Fritiofson <andreas.fritiofson@gmail.com>2016-05-17 21:52:30 +0100
commit150b7d26f213398d717bf46744811b48834a3744 (patch)
treeffc64ea1eecf05cd26f6b17dca1d26c3ce26f672 /src/target/adi_v5_swd.c
parent56a889f4d46125f8a322d0ca468774b6a5703f97 (diff)
downloadriscv-openocd-150b7d26f213398d717bf46744811b48834a3744.zip
riscv-openocd-150b7d26f213398d717bf46744811b48834a3744.tar.gz
riscv-openocd-150b7d26f213398d717bf46744811b48834a3744.tar.bz2
arm_adi_v5: Update DP (Debug Port) registers defined in ADIv5.2.
Note: WCR (Wire Control Register) is replaced by DLCR (Data Link Control Register). And only TURNROUND field is modifiable. [andreas.fritiofson@gmail.com]: Rename DP_IDCODE to DP_DPIDR as well. Sort list by address and align it using spaces instead of tabs. Add comments about supporting DP versions. Remove non-functional wcr command completely. Change-Id: Ic6b781b07c8eead8b0237d497846d0da060cb1ba Signed-off-by: Alamy Liu <alamy.liu@gmail.com> Signed-off-by: Andreas Fritiofson <andreas.fritiofson@gmail.com> Reviewed-on: http://openocd.zylin.com/3244 Tested-by: jenkins
Diffstat (limited to 'src/target/adi_v5_swd.c')
-rw-r--r--src/target/adi_v5_swd.c72
1 files changed, 4 insertions, 68 deletions
diff --git a/src/target/adi_v5_swd.c b/src/target/adi_v5_swd.c
index 771b460..d1a4870 100644
--- a/src/target/adi_v5_swd.c
+++ b/src/target/adi_v5_swd.c
@@ -99,14 +99,14 @@ static int swd_run_inner(struct adiv5_dap *dap)
static int swd_connect(struct adiv5_dap *dap)
{
- uint32_t idcode;
+ uint32_t dpidr;
int status;
/* FIXME validate transport config ... is the
* configured DAP present (check IDCODE)?
* Is *only* one DAP configured?
*
* MUST READ IDCODE
*/
/* Note, debugport_init() does setup too */
@@ -116,7 +116,7 @@ static int swd_connect(struct adiv5_dap *dap)
dap->do_reconnect = false;
dap->select = DP_SELECT_INVALID;
- swd_queue_dp_read(dap, DP_IDCODE, &idcode);
+ swd_queue_dp_read(dap, DP_DPIDR, &dpidr);
/* force clear all sticky faults */
swd_clear_sticky_errors(dap);
@@ -124,7 +124,7 @@ static int swd_connect(struct adiv5_dap *dap)
status = swd_run_inner(dap);
if (status == ERROR_OK) {
- LOG_INFO("SWD IDCODE %#8.8" PRIx32, idcode);
+ LOG_INFO("SWD DPIDR %#8.8" PRIx32, dpidr);
dap->do_reconnect = false;
} else
dap->do_reconnect = true;
@@ -342,61 +342,6 @@ int dap_to_swd(struct target *target)
return retval;
}
-COMMAND_HANDLER(handle_swd_wcr)
-{
- int retval;
- struct target *target = get_current_target(CMD_CTX);
- struct arm *arm = target_to_arm(target);
- struct adiv5_dap *dap = arm->dap;
- uint32_t wcr;
- unsigned trn, scale = 0;
-
- switch (CMD_ARGC) {
- /* no-args: just dump state */
- case 0:
- /*retval = swd_queue_dp_read(dap, DP_WCR, &wcr); */
- retval = dap_queue_dp_read(dap, DP_WCR, &wcr);
- if (retval == ERROR_OK)
- dap->ops->run(dap);
- if (retval != ERROR_OK) {
- LOG_ERROR("can't read WCR?");
- return retval;
- }
-
- command_print(CMD_CTX,
- "turnaround=%" PRIu32 ", prescale=%" PRIu32,
- WCR_TO_TRN(wcr),
- WCR_TO_PRESCALE(wcr));
- return ERROR_OK;
-
- case 2: /* TRN and prescale */
- COMMAND_PARSE_NUMBER(uint, CMD_ARGV[1], scale);
- if (scale > 7) {
- LOG_ERROR("prescale %d is too big", scale);
- return ERROR_FAIL;
- }
- /* FALL THROUGH */
-
- case 1: /* TRN only */
- COMMAND_PARSE_NUMBER(uint, CMD_ARGV[0], trn);
- if (trn < 1 || trn > 4) {
- LOG_ERROR("turnaround %d is invalid", trn);
- return ERROR_FAIL;
- }
-
- wcr = ((trn - 1) << 8) | scale;
- /* FIXME
- * write WCR ...
- * then, re-init adapter with new TRN
- */
- LOG_ERROR("can't yet modify WCR");
- return ERROR_FAIL;
-
- default: /* too many arguments */
- return ERROR_COMMAND_SYNTAX_ERROR;
- }
-}
-
static const struct command_registration swd_commands[] = {
{
/*
@@ -411,15 +356,6 @@ static const struct command_registration swd_commands[] = {
.mode = COMMAND_CONFIG,
.help = "declare a new SWD DAP"
},
- {
- .name = "wcr",
- .handler = handle_swd_wcr,
- .mode = COMMAND_ANY,
- .help = "display or update DAP's WCR register",
- .usage = "turnaround (1..4), prescale (0..7)",
- },
-
- /* REVISIT -- add a command for SWV trace on/off */
COMMAND_REGISTRATION_DONE
};
@@ -99,14 +99,14 @@ static int swd_run_inner(struct adiv5_dap *dap)
* Is *only* one DAP configured?
*
- * MUST READ IDCODE
+ * MUST READ DPIDR
*/
/* Note, debugport_init() does setup too */